@@ -258,49 +258,49 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTableInterface")
     def dynamo_table_interface(self) -> aws_cdk.aws_dynamodb.ITable:
         return typing.cast(aws_cdk.aws_dynamodb.ITable, jsii.get(self, "dynamoTableInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="elasticsearchDomain")
     def elasticsearch_domain(self) -> aws_cdk.aws_elasticsearch.CfnDomain:
         return typing.cast(aws_cdk.aws_elasticsearch.CfnDomain, jsii.get(self, "elasticsearchDomain"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="elasticsearchRole")
     def elasticsearch_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "elasticsearchRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="identityPool")
     def identity_pool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
         return typing.cast(aws_cdk.aws_cognito.CfnIdentityPool, jsii.get(self, "identityPool"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="userPool")
     def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
         return typing.cast(aws_cdk.aws_cognito.UserPool, jsii.get(self, "userPool"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="userPoolClient")
     def user_pool_client(self) -> aws_cdk.aws_cognito.UserPoolClient:
         return typing.cast(aws_cdk.aws_cognito.UserPoolClient, jsii.get(self, "userPoolClient"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], jsii.get(self, "dynamoTable"))
@@ -355,15 +355,15 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         :summary: The properties for the DynamoDBStreamToLambdaToElastciSearchAndKibana Construct
         '''
         if isinstance(dynamo_event_source_props, dict):
-            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
+            dynamo_event_source_props = DynamoEventSourceProps(**dynamo_event_source_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = TableProps(**dynamo_table_props)
         if isinstance(es_domain_props, dict):
-            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
+            es_domain_props = CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
-            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+            sqs_dlq_queue_props = QueueProps(**sqs_dlq_queue_props)
         if __debug__:
             type_hints = typing.get_type_hints(DynamoDBStreamToLambdaToElasticSearchAndKibanaProps.__init__)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
